"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeReanimated = _interopRequireDefault(require("react-native-reanimated"));
var _reactNativeRedash = require("react-native-redash");
var _lodash = _interopRequireDefault(require("lodash.isequal"));
var _utilities = require("../../../utilities");
var _styles = require("./styles");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// @ts-ignore 😞

const {
  add
} = _reactNativeReanimated.default;
const BubbleTabBarItemComponent = _ref => {
  let {
    animatedFocus,
    label,
    icon,
    background,
    labelStyle: labelStyleOverride,
    spacing,
    iconSize,
    isRTL
  } = _ref;
  //#region extract props
  const {
    innerVerticalSpace,
    innerHorizontalSpace,
    outerVerticalSpace,
    outerHorizontalSpace
  } = spacing;
  //#endregion

  //#region variables
  const labelWidth = (0, _reactNativeRedash.useValue)(0);
  /**
   * @DEV
   * min width is calculated by adding outer & inner spaces
   * with the icon size.
   */
  const minWidth = (0, _react.useMemo)(() => {
    return innerHorizontalSpace * 2 + iconSize + outerHorizontalSpace * 2;
  }, [innerHorizontalSpace, outerHorizontalSpace, iconSize]);
  /**
   * @DEV
   * max width is calculated by adding inner space with label width
   */
  const maxWidth = add(labelWidth, innerHorizontalSpace, minWidth);
  //#endregion

  //#region styles
  const animatedIconColor = (0, _reactNativeRedash.interpolateColor)(animatedFocus, {
    inputRange: [0, 1],
    outputRange: [icon.inactiveColor, icon.activeColor]
  });
  const containerStyle = [_styles.styles.container, {
    paddingHorizontal: outerHorizontalSpace,
    paddingVertical: outerVerticalSpace,
    width: (0, _utilities.interpolate)(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [minWidth, maxWidth]
    })
  }];
  const contentContainerStyle = [_styles.styles.contentContainer, {
    flexDirection: isRTL ? 'row-reverse' : 'row',
    paddingHorizontal: innerHorizontalSpace,
    paddingVertical: innerVerticalSpace,
    borderRadius: innerVerticalSpace * 2 + iconSize,
    backgroundColor: (0, _reactNativeRedash.interpolateColor)(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [background.inactiveColor, background.activeColor]
    })
  }];
  const labelContainerStyle = [_styles.styles.labelContainer, {
    opacity: (0, _utilities.interpolate)(animatedFocus, {
      inputRange: [0.33, 1],
      outputRange: [0, 1]
    }),
    [isRTL ? 'left' : 'right']: (0, _utilities.interpolate)(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [0, innerHorizontalSpace + outerHorizontalSpace]
    })
  }];
  const iconContainerStyle = [_styles.styles.iconContainer, {
    minHeight: iconSize,
    minWidth: iconSize
  }];
  const labelStyle = [_styles.styles.label, labelStyleOverride];
  //#endregion

  // callbacks
  const handleTextLayout = _ref2 => {
    let {
      nativeEvent: {
        layout: {
          width
        }
      }
    } = _ref2;
    return requestAnimationFrame(() => labelWidth.setValue(width));
  };

  // render
  const renderIcon = () => {
    const IconComponent = icon.component;
    return typeof IconComponent === 'function' ? IconComponent({
      animatedFocus,
      color: animatedIconColor,
      size: iconSize
    }) : /*#__PURE__*/_react.default.createElement(IconComponent, {
      animatedFocus: animatedFocus,
      color: animatedIconColor,
      size: iconSize
    });
  };
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: containerStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: contentContainerStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: iconContainerStyle
  }, renderIcon())), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: labelContainerStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    onLayout: handleTextLayout,
    style: labelStyle,
    numberOfLines: 1
  }, label)));
};
const BubbleTabBarItem = /*#__PURE__*/(0, _react.memo)(BubbleTabBarItemComponent, _lodash.default);
var _default = BubbleTabBarItem;
exports.default = _default;
//# sourceMappingURL=BubbleTabBarItem.js.map