import React, { useMemo, memo } from 'react';
import { View, Text } from 'react-native';
import Animated from 'react-native-reanimated';
import { interpolateColor, useValue } from 'react-native-redash';
// @ts-ignore 😞
import isEqual from 'lodash.isequal';
import { interpolate } from '../../../utilities';
import { styles } from './styles';
const {
  add
} = Animated;
const BubbleTabBarItemComponent = _ref => {
  let {
    animatedFocus,
    label,
    icon,
    background,
    labelStyle: labelStyleOverride,
    spacing,
    iconSize,
    isRTL
  } = _ref;
  //#region extract props
  const {
    innerVerticalSpace,
    innerHorizontalSpace,
    outerVerticalSpace,
    outerHorizontalSpace
  } = spacing;
  //#endregion

  //#region variables
  const labelWidth = useValue(0);
  /**
   * @DEV
   * min width is calculated by adding outer & inner spaces
   * with the icon size.
   */
  const minWidth = useMemo(() => {
    return innerHorizontalSpace * 2 + iconSize + outerHorizontalSpace * 2;
  }, [innerHorizontalSpace, outerHorizontalSpace, iconSize]);
  /**
   * @DEV
   * max width is calculated by adding inner space with label width
   */
  const maxWidth = add(labelWidth, innerHorizontalSpace, minWidth);
  //#endregion

  //#region styles
  const animatedIconColor = interpolateColor(animatedFocus, {
    inputRange: [0, 1],
    outputRange: [icon.inactiveColor, icon.activeColor]
  });
  const containerStyle = [styles.container, {
    paddingHorizontal: outerHorizontalSpace,
    paddingVertical: outerVerticalSpace,
    width: interpolate(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [minWidth, maxWidth]
    })
  }];
  const contentContainerStyle = [styles.contentContainer, {
    flexDirection: isRTL ? 'row-reverse' : 'row',
    paddingHorizontal: innerHorizontalSpace,
    paddingVertical: innerVerticalSpace,
    borderRadius: innerVerticalSpace * 2 + iconSize,
    backgroundColor: interpolateColor(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [background.inactiveColor, background.activeColor]
    })
  }];
  const labelContainerStyle = [styles.labelContainer, {
    opacity: interpolate(animatedFocus, {
      inputRange: [0.33, 1],
      outputRange: [0, 1]
    }),
    [isRTL ? 'left' : 'right']: interpolate(animatedFocus, {
      inputRange: [0, 1],
      outputRange: [0, innerHorizontalSpace + outerHorizontalSpace]
    })
  }];
  const iconContainerStyle = [styles.iconContainer, {
    minHeight: iconSize,
    minWidth: iconSize
  }];
  const labelStyle = [styles.label, labelStyleOverride];
  //#endregion

  // callbacks
  const handleTextLayout = _ref2 => {
    let {
      nativeEvent: {
        layout: {
          width
        }
      }
    } = _ref2;
    return requestAnimationFrame(() => labelWidth.setValue(width));
  };

  // render
  const renderIcon = () => {
    const IconComponent = icon.component;
    return typeof IconComponent === 'function' ? IconComponent({
      animatedFocus,
      color: animatedIconColor,
      size: iconSize
    }) : /*#__PURE__*/React.createElement(IconComponent, {
      animatedFocus: animatedFocus,
      color: animatedIconColor,
      size: iconSize
    });
  };
  return /*#__PURE__*/React.createElement(Animated.View, {
    style: containerStyle
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: contentContainerStyle
  }, /*#__PURE__*/React.createElement(View, {
    style: iconContainerStyle
  }, renderIcon())), /*#__PURE__*/React.createElement(Animated.View, {
    style: labelContainerStyle
  }, /*#__PURE__*/React.createElement(Text, {
    onLayout: handleTextLayout,
    style: labelStyle,
    numberOfLines: 1
  }, label)));
};
const BubbleTabBarItem = /*#__PURE__*/memo(BubbleTabBarItemComponent, isEqual);
export default BubbleTabBarItem;
//# sourceMappingURL=BubbleTabBarItem.js.map